@@ -2,7 +2,7 @@
     Main file of the Smb4K program.
                              -------------------
     begin                : Sam Mär  1 14:57:21 CET 2003
-    copyright            : (C) 2003-2020 by Alexander Reinholdt
+    copyright            : (C) 2003-2022 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -47,97 +47,6 @@ using namespace Smb4KGlobal;
 
 int main(int argc, char **argv)
 {
-  // Migrate KDE4 configuration and XML files 
-  QStringList configFiles;
-  configFiles << QLatin1String("smb4krc");
-  
-  Kdelibs4ConfigMigrator migrator(QLatin1String("smb4k"));
-  migrator.setConfigFiles(configFiles);
-  
-  if (migrator.migrate())
-  {
-    Kdelibs4Migration migration;
-    
-    if (migration.kdeHomeFound())
-    {
-      //
-      // NOTE: We need the 'smb4k' subdirectory, since no QApplication 
-      // is running at this point.
-      //
-      
-      // New location
-      QString path = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation)+QDir::separator()+"smb4k";
-      
-      // XML files
-      QString bookmarks = migration.locateLocal("data", "smb4k/bookmarks.xml");
-      QString options = migration.locateLocal("data", "smb4k/custom_options.xml");
-      QString homes = migration.locateLocal("data", "smb4k/homes_shares.xml");
-      
-      // Copy the files if they don't already exist
-      if (!bookmarks.isEmpty() && QFile().exists(bookmarks))
-      {
-        if (!QDir().exists(path))
-        {
-          QDir().mkpath(path);
-        }
-        else
-        {
-          // Do nothing
-        }
-        
-        QFile(bookmarks).copy(path+QDir::separator()+"bookmarks.xml");
-      }
-      else
-      {
-        // Do nothing
-      }
-      
-      if (!options.isEmpty() && QFile().exists(options))
-      {
-        if (!QDir().exists(path))
-        {
-          QDir().mkpath(path);
-        }
-        else
-        {
-          // Do nothing
-        }
-        
-        QFile(options).copy(path+QDir::separator()+"custom_options.xml");
-      }
-      else
-      {
-        // Do nothing
-      }
-      
-      if (!homes.isEmpty() && QFile().exists(homes))
-      {
-        if (!QDir().exists(path))
-        {
-          QDir().mkpath(path);
-        }
-        else
-        {
-          // Do nothing
-        }
-        
-        QFile(homes).copy(path+QDir::separator()+"homes_shares.xml");
-      }
-      else
-      {
-        // Do nothing
-      }
-    }
-    else
-    {
-      // Do nothing
-    }
-  }
-  else
-  {
-    // Do nothing
-  }
-  
   // Set attributes
   QApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
   QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
@@ -151,7 +60,7 @@ int main(int argc, char **argv)
   // Create the about data for Smb4K  
   KAboutData aboutData(QStringLiteral("smb4k"), i18n("Smb4K"), QStringLiteral(SMB4K_VERSION_STRING),
     i18n("Advanced network neighborhood browser and Samba share mounting utility"),
-    KAboutLicense::GPL_V2, i18n("\u00A9 2003-2021 Alexander Reinholdt"), QString(), 
+    KAboutLicense::GPL_V2, i18n("\u00A9 2003-2022 Alexander Reinholdt"), QString(), 
     QStringLiteral("https://smb4k.sourceforge.io"));
   
   // DBus prefix
